@@ -1,4 +1,6 @@
-from mindee.documents import Document
+from typing import List, Optional
+
+from mindee.documents.base import Document
 from mindee.fields import Field
 from mindee.fields.date import Date
 from mindee.fields.amount import Amount
@@ -6,10 +8,25 @@ from mindee.fields.locale import Locale
 from mindee.fields.orientation import Orientation
 from mindee.fields.payment_details import PaymentDetails
 from mindee.fields.tax import Tax
-from mindee.http import make_api_request, make_predict_url
+from mindee.http import make_api_request, API_TYPE_OFF_THE_SHELF, Endpoint
+from mindee.document_config import DocumentConfig
 
 
 class Invoice(Document):
+    locale: Locale
+    total_incl: Amount
+    total_excl: Amount
+    invoice_date: Date
+    invoice_number: Field
+    due_date: Date
+    taxes: List[Tax] = []
+    supplier: Field
+    payment_details: List[PaymentDetails] = []
+    company_number: List[Field] = []
+    total_tax: Amount
+    # orientation is only present on page-level, not document-level
+    orientation: Optional[Orientation] = None
+
     def __init__(
         self,
         api_prediction=None,
@@ -27,6 +44,7 @@ class Invoice(Document):
         orientation=None,
         total_tax=None,
         page_n=0,
+        document_type="invoice",
     ):
         """
         :param api_prediction: Raw prediction from HTTP response
@@ -41,24 +59,17 @@ class Invoice(Document):
         :param supplier: supplier value for creating Invoice object from scratch
         :param payment_details: payment_details value for creating Invoice object from scratch
         :param company_number: company_number value for creating Invoice object from scratch
-        :param vat_number: vat_number value for creating Invoice object from scratch
         :param orientation: orientation value for creating Invoice object from scratch
         :param total_tax: total_tax value for creating Invoice object from scratch
         :param page_n: Page number for multi pages pdf input
         """
-        self.type = "Invoice"
-        self.locale = None
-        self.total_incl = None
-        self.total_excl = None
-        self.invoice_date = None
-        self.invoice_number = None
-        self.due_date = None
-        self.taxes = []
-        self.supplier = None
-        self.payment_details = None
-        self.company_number = None
-        self.orientation = None
-        self.total_tax = None
+        # Invoke Document constructor
+        super().__init__(
+            input_file=input_file,
+            document_type=document_type,
+            api_prediction=api_prediction,
+            page_n=page_n,
+        )
 
         if api_prediction is not None:
             self.build_from_api_prediction(api_prediction, page_n=page_n)
@@ -94,15 +105,14 @@ class Invoice(Document):
             self.invoice_number = Field(
                 {"value": invoice_number}, value_key="value", page_n=page_n
             )
-            self.payment_details = Field(
-                {"value": payment_details}, value_key="value", page_n=page_n
-            )
-            self.company_number = Field(
-                {"value": company_number}, value_key="value", page_n=page_n
-            )
-
-        # Invoke Document constructor
-        super(Invoice, self).__init__(input_file)
+            self.payment_details = [
+                PaymentDetails(
+                    {"value": payment_details}, value_key="value", page_n=page_n
+                )
+            ]
+            self.company_number = [
+                Field({"value": company_number}, value_key="value", page_n=page_n)
+            ]
 
         # Run checks
         self._checklist()
@@ -110,6 +120,27 @@ class Invoice(Document):
         # Reconstruct extra fields
         self._reconstruct()
 
+    @staticmethod
+    def get_document_config() -> DocumentConfig:
+        """:return: the configuration for invoice"""
+        return DocumentConfig(
+            {
+                "constructor": Invoice,
+                "endpoints": [
+                    Endpoint(
+                        owner="mindee",
+                        url_name="invoices",
+                        version="2",
+                        key_name="invoice",
+                    )
+                ],
+                "document_type": "invoice",
+                "singular_name": "invoice",
+                "plural_name": "invoices",
+            },
+            api_type=API_TYPE_OFF_THE_SHELF,
+        )
+
     def build_from_api_prediction(self, api_prediction: dict, page_n=0):
         """
         :param api_prediction: Raw prediction from HTTP response
@@ -161,6 +192,7 @@ class Invoice(Document):
             "Invoice date: %s\n"
             "Invoice due date: %s\n"
             "Supplier name: %s\n"
+            "Payment details: %s\n"
             "Taxes: %s\n"
             "Total taxes: %s\n"
             "----------------------"
@@ -172,41 +204,23 @@ class Invoice(Document):
                 self.invoice_date.value,
                 self.due_date.value,
                 self.supplier.value,
+                self.payment_details,
                 ",".join([str(t.value) + " " + str(t.rate) + "%" for t in self.taxes]),
                 self.total_tax.value,
             )
         )
 
     @staticmethod
-    def compare(invoice=None, ground_truth=None):
+    def request(endpoints: List[Endpoint], input_file, include_words=False):
         """
-        :param invoice: Invoice object to compare
-        :param ground_truth: Ground truth Invoice object
-        :return: Accuracy and precisions metrics
-        """
-        assert invoice is not None
-        assert ground_truth is not None
-        assert isinstance(invoice, Invoice)
-        assert isinstance(ground_truth, Invoice)
-
-        metrics = {}
-
-        # Compute Accuracy metrics
-        metrics.update(Invoice.compute_accuracy(invoice, ground_truth))
-
-        return metrics
-
-    @staticmethod
-    def request(input_file, invoice_token, version="2", include_words=False):
-        """
-        Make request to invoices endpoint
+        Make request to expense_receipts endpoint
         :param input_file: Input object
-        :param invoice_token: Invoices API token
+        :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
-        :param version: API version
         """
-        url = make_predict_url("invoices", version)
-        return make_api_request(url, input_file, invoice_token, include_words)
+        return make_api_request(
+            endpoints[0].predict_url, input_file, endpoints[0].api_key, include_words
+        )
 
     def _reconstruct(self):
         """
@@ -228,13 +242,13 @@ class Invoice(Document):
         }
 
     # Checks
-    def __taxes_match_total_incl(self):
+    def __taxes_match_total_incl(self) -> bool:
         """
         Check invoice rule of matching between taxes and total_incl
         :return: True if rule matches, False otherwise
         """
-        # Check taxes and total_incl exist
-        if len(self.taxes) == 0 or self.total_incl.value is None:
+        # Ensure taxes and total_incl exist
+        if not self.taxes or not self.total_incl.value:
             return False
 
         # Reconstruct total_incl from taxes
@@ -252,19 +266,17 @@ class Invoice(Document):
 
         # Crate epsilon
         eps = 1 / (100 * total_vat)
-
         if (
             self.total_incl.value * (1 - eps) - 0.02
             <= reconstructed_total
             <= self.total_incl.value * (1 + eps) + 0.02
         ):
             for tax in self.taxes:
-                tax.probability = 1
-            self.total_tax.probability = 1.0
-            self.total_incl.probability = 1.0
+                tax.confidence = 1
+            self.total_tax.confidence = 1.0
+            self.total_incl.confidence = 1.0
             return True
-        else:
-            return False
+        return False
 
     def __taxes_match_total_excl(self):
         """
@@ -290,7 +302,6 @@ class Invoice(Document):
 
         # Crate epsilon
         eps = 1 / (100 * total_vat)
-
         # Check that reconstructed total excl matches total excl
         if (
             self.total_excl.value * (1 - eps) - 0.02
@@ -298,12 +309,11 @@ class Invoice(Document):
             <= self.total_excl.value * (1 + eps) + 0.02
         ):
             for tax in self.taxes:
-                tax.probability = 1
-            self.total_tax.probability = 1.0
-            self.total_excl.probability = 1.0
+                tax.confidence = 1
+            self.total_tax.confidence = 1.0
+            self.total_excl.confidence = 1.0
             return True
-        else:
-            return False
+        return False
 
     def __taxes_plus_total_excl_match_total_incl(self):
         """
@@ -335,20 +345,19 @@ class Invoice(Document):
             <= self.total_incl.value + 0.01
         ):
             for tax in self.taxes:
-                tax.probability = 1
-            self.total_tax.probability = 1.0
-            self.total_excl.probability = 1.0
-            self.total_incl.probability = 1.0
+                tax.confidence = 1
+            self.total_tax.confidence = 1.0
+            self.total_excl.confidence = 1.0
+            self.total_incl.confidence = 1.0
             return True
-        else:
-            return False
+        return False
 
     # Reconstruct
     def __reconstruct_total_incl_from_taxes_plus_excl(self):
         """
         Set self.total_incl with Amount object
         The total_incl Amount value is the sum of total_excl and sum of taxes
-        The total_incl Amount probability is the product of self.taxes probabilities multiplied by total_excl probability
+        The total_incl Amount confidence is the product of self.taxes probabilities multiplied by total_excl confidence
         """
         # Check total_tax, total excl exist and total incl is not set
         if (
@@ -363,8 +372,8 @@ class Invoice(Document):
                     [tax.value if tax.value is not None else 0 for tax in self.taxes]
                 )
                 + self.total_excl.value,
-                "confidence": Field.array_probability(self.taxes)
-                * self.total_excl.probability,
+                "confidence": Field.array_confidence(self.taxes)
+                * self.total_excl.confidence,
             }
             self.total_incl = Amount(total_incl, value_key="value", reconstructed=True)
 
@@ -372,7 +381,7 @@ class Invoice(Document):
         """
         Set self.total_excl with Amount object
         The total_excl Amount value is the difference between total_incl and sum of taxes
-        The total_excl Amount probability is the product of self.taxes probabilities multiplied by total_incl probability
+        The total_excl Amount confidence is the product of self.taxes probabilities multiplied by total_incl confidence
         """
         # Check total_tax, total excl and total incl exist
         if (
@@ -387,8 +396,8 @@ class Invoice(Document):
                 - sum(
                     [tax.value if tax.value is not None else 0 for tax in self.taxes]
                 ),
-                "confidence": Field.array_probability(self.taxes)
-                * self.total_incl.probability,
+                "confidence": Field.array_confidence(self.taxes)
+                * self.total_incl.confidence,
             }
             self.total_excl = Amount(total_excl, value_key="value", reconstructed=True)
 
@@ -396,14 +405,14 @@ class Invoice(Document):
         """
         Set self.total_tax with Amount object
         The total_tax Amount value is the sum of all self.taxes value
-        The total_tax Amount probability is the product of self.taxes probabilities
+        The total_tax Amount confidence is the product of self.taxes probabilities
         """
-        if len(self.taxes):
+        if self.taxes:
             total_tax = {
                 "value": sum(
                     [tax.value if tax.value is not None else 0 for tax in self.taxes]
                 ),
-                "confidence": Field.array_probability(self.taxes),
+                "confidence": Field.array_confidence(self.taxes),
             }
             if total_tax["value"] > 0:
                 self.total_tax = Amount(
@@ -426,27 +435,9 @@ class Invoice(Document):
 
             total_tax = {
                 "value": self.total_incl.value - self.total_excl.value,
-                "confidence": self.total_incl.probability * self.total_excl.probability,
+                "confidence": self.total_incl.confidence * self.total_excl.confidence,
             }
             if total_tax["value"] >= 0:
                 self.total_tax = Amount(
                     total_tax, value_key="value", reconstructed=True
                 )
-
-    @staticmethod
-    def compute_accuracy(invoice, ground_truth):
-        """
-        :param invoice: Invoice object to compare
-        :param ground_truth: Ground truth Invoice object
-        :return: Accuracy metrics
-        """
-        return {
-            "__acc__total_incl": ground_truth.total_incl == invoice.total_incl,
-            "__acc__total_excl": ground_truth.total_excl == invoice.total_excl,
-            "__acc__invoice_date": ground_truth.invoice_date == invoice.invoice_date,
-            "__acc__invoice_number": ground_truth.invoice_number
-            == invoice.invoice_number,
-            "__acc__due_date": ground_truth.due_date == invoice.due_date,
-            "__acc__total_tax": ground_truth.total_tax == invoice.total_tax,
-            "__acc__taxes": Tax.compare_arrays(invoice.taxes, ground_truth.taxes),
-        }
