@@ -1,6 +1,6 @@
 import json
 import pytest
-from mindee import Invoice
+from mindee.documents.invoice import Invoice
 
 
 @pytest.fixture
@@ -48,9 +48,9 @@ def test_constructor(invoice_object):
     assert invoice_object.checklist["taxes_plus_total_excl_match_total_incl"] is True
     assert invoice_object.total_tax.value == 97.98
     assert invoice_object.invoice_date.value == "2020-02-17"
-    assert invoice_object.invoice_date.probability == 0.97
+    assert invoice_object.invoice_date.confidence == 0.97
     assert invoice_object.invoice_number.value == "0042004801351"
-    assert invoice_object.invoice_number.probability == 0.95
+    assert invoice_object.invoice_number.confidence == 0.95
     assert isinstance(invoice_object.__str__(), str)
 
 
@@ -99,7 +99,7 @@ def test__reconstruct_total_incl_from_taxes_plus_excl_3(invoice_pred):
     invoice_pred["taxes"] = [{"rate": 20, "value": 9.5, "confidence": 0.9}]
     invoice = Invoice(invoice_pred)
     assert invoice.total_incl.value == 260
-    assert invoice.total_incl.probability == 0.4
+    assert invoice.total_incl.confidence == 0.4
 
 
 def test__reconstruct_total_incl_from_taxes_plus_excl_4(invoice_pred):
@@ -109,7 +109,7 @@ def test__reconstruct_total_incl_from_taxes_plus_excl_4(invoice_pred):
     invoice_pred["taxes"] = [{"rate": 20, "value": 9.5, "confidence": 0.9}]
     invoice = Invoice(invoice_pred)
     assert invoice.total_incl.value == 250
-    assert invoice.total_incl.probability == 0.81
+    assert invoice.total_incl.confidence == 0.81
 
 
 def test__reconstruct_total_excl_from_tcc_and_taxes_1(invoice_pred):
@@ -137,7 +137,7 @@ def test__reconstruct_total_excl_from_tcc_and_taxes_3(invoice_pred):
     invoice_pred["taxes"] = []
     invoice = Invoice(invoice_pred)
     assert invoice.total_excl.value == 1050.0
-    assert invoice.total_excl.probability == 0.4
+    assert invoice.total_excl.confidence == 0.4
 
 
 def test__reconstruct_total_excl_from_tcc_and_taxes_4(invoice_pred):
@@ -150,7 +150,7 @@ def test__reconstruct_total_excl_from_tcc_and_taxes_4(invoice_pred):
     ]
     invoice = Invoice(invoice_pred)
     assert invoice.total_excl.value == 1100
-    assert invoice.total_excl.probability == 0.03
+    assert invoice.total_excl.confidence == 0.03
 
 
 def test__reconstruct_total_tax_1(invoice_pred):
@@ -168,7 +168,7 @@ def test__reconstruct_total_tax_2(invoice_pred):
     ]
     invoice = Invoice(invoice_pred)
     assert invoice.total_tax.value == 50.2
-    assert invoice.total_tax.probability == 0.05
+    assert invoice.total_tax.confidence == 0.05
 
 
 def test__taxes_match_total_incl_1(invoice_pred):
@@ -180,9 +180,9 @@ def test__taxes_match_total_incl_1(invoice_pred):
     ]
     invoice = Invoice(invoice_pred)
     assert invoice.checklist["taxes_match_total_incl"] is True
-    assert invoice.total_incl.probability == 1.0
+    assert invoice.total_incl.confidence == 1.0
     for tax in invoice.taxes:
-        assert tax.probability == 1.0
+        assert tax.confidence == 1.0
 
 
 def test__taxes_match_total_incl_2(invoice_pred):
@@ -213,9 +213,9 @@ def test__taxes_match_total_excl_1(invoice_pred):
     ]
     invoice = Invoice(invoice_pred)
     assert invoice.checklist["taxes_match_total_excl"] is True
-    assert invoice.total_excl.probability == 1.0
+    assert invoice.total_excl.confidence == 1.0
     for tax in invoice.taxes:
-        assert tax.probability == 1.0
+        assert tax.confidence == 1.0
 
 
 def test__taxes_match_total_excl_2(invoice_pred):
@@ -247,10 +247,10 @@ def test__taxes_plus_total_excl_match_total_incl_1(invoice_pred):
     ]
     invoice = Invoice(invoice_pred)
     assert invoice.checklist["taxes_plus_total_excl_match_total_incl"] is True
-    assert invoice.total_incl.probability == 1.0
-    assert invoice.total_excl.probability == 1.0
+    assert invoice.total_incl.confidence == 1.0
+    assert invoice.total_excl.confidence == 1.0
     for tax in invoice.taxes:
-        assert tax.probability == 1.0
+        assert tax.confidence == 1.0
 
 
 def test__taxes_plus_total_excl_match_total_incl_2(invoice_pred):
@@ -283,43 +283,6 @@ def test__shouldnt_raise_when_tax_rate_none(invoice_pred):
     assert invoice.checklist["taxes_match_total_incl"] is False
 
 
-def test_compare_1(invoice_object):
-    # Compare same object must return all True
-    benchmark = Invoice.compare(invoice_object, invoice_object)
-    for value in benchmark.values():
-        assert value is True
-
-
-def test_compare_2(invoice_object, invoice_object_all_na):
-    # Compare full object and empty object
-    benchmark = Invoice.compare(invoice_object, invoice_object_all_na)
-    for key in benchmark.keys():
-        assert benchmark[key] is False
-
-
-def test_compare_3(invoice_object_from_scratch):
-    # Compare invoice from class
-    benchmark = Invoice.compare(
-        invoice_object_from_scratch, invoice_object_from_scratch
-    )
-    for key in benchmark.keys():
-        if "__acc__" in key:
-            assert benchmark[key] is True
-
-
-def test_compare_4(invoice_object_from_scratch):
-    # Compare invoice from class with empty taxes
-    invoice_object_from_scratch.taxes = []
-    benchmark = Invoice.compare(
-        invoice_object_from_scratch, invoice_object_from_scratch
-    )
-    for key in benchmark.keys():
-        if "__acc__" in key:
-            assert benchmark[key] is True
-        elif "__pre__" in key:
-            assert benchmark[key] in [True, None]
-
-
 def test_empty_object_works():
     invoice = Invoice()
     assert invoice.total_tax.value is None
